//To import statements from D3 library
import {select,
        csv,
        scaleLinear,
        max, 
        scaleBand,
        axisLeft,
        axisBottom
       } from 'd3';
// The Label names for x-axis and the graph size
const svg = select('svg');
const xlabel = 'North_West';

const width = +svg.attr('width');
const height = +svg.attr('height');
// The CSS for the hover over bar graph
      const tooltip = d3.select("body")
        .append("div")
        .attr("class","d3-tooltip")
        .style("position", "absolute")
        .style("z-index", "10")
        .style("visibility", "hidden")
        .style("padding", "15px")
        .style("background", "rgba(0,0,0,0.6)")
        .style("border-radius", "5px")
        .style("color", "#fff")
        .text("a simple tooltip");


const render = data => {
  const xValue = d => d.North_East;
  const yValue = d=>d.Year;
  const margin = {top:20,right:20,left:100,bottom:20};
  const innerWidth = width - margin.left - margin.right
  const innerHeight  = height - margin.top - margin.bottom
  const xScale = scaleLinear()
    .domain([0,max(data,xValue)])
    .range([0,innerWidth]);
  
  const yScale =scaleBand()
  	.domain(data.map(yValue))
  	.range([0,innerHeight])
  	.padding(0.1);
  const yAxis = axisLeft(yScale);
  
  const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`)
  
  yAxis(g.append('g'));
  
  g.append('g').call(axisBottom(xScale))
  	.attr('transform',`translate(0,${innerHeight})`);

  g.append('text')
  	.attr('class','title')
  	.attr('y',0)
  	.attr('x',200)
  	.text("Houses sold(in Thousands) in each year");
  
  g.selectAll('rect').data(data)
  .enter().append('rect')
  	.attr('y',d => yScale(yValue(d)))
    .attr('width',d => xScale(xValue(d)))
  	.attr('height',yScale.bandwidth())
    .on("mouseover", function(event,d) {
      tooltip.html(`${d.Year} Sales ${d.North_East}`).style("visibility", "visible");
      d3.select(this)
        .attr("fill", shadeColor(bar_color, -15));
    })
    .on("mousemove", function(){
      tooltip
        .style("top", (event.pageY-10)+"px")
        .style("left",(event.pageX+10)+"px");
    })
    .on("mouseout", function() {
      tooltip.html(``).style("visibility", "hidden");
      d3.select(this).attr("fill", bar_color);
    });
};
const dataUrl="https://gist.githubusercontent.com/sampath5/8838065c51fc7161a7638258775e4c67/raw/ddaafbc2fef994f907faae02f651a26b73cd0469/yearwisesales.csv"
csv(dataUrl).then(data => {
  data.forEach( d => {
    d.United_States  = +d.United_States;
  });
  render(data);
});